@@ -1,11 +1,17 @@
 import click
 from click.exceptions import ClickException
 
+
 class EjudgeError(ClickException):
     def __init__(self, message='unknown error'):
         super().__init__(message)
 
 
+class EjudgeUnavailableError(EjudgeError):
+    def __init__(self, message='Ejudge is not available'):
+        super().__init__(message)
+
+
 class AuthError(EjudgeError):
     def __init__(self, message='Auth error', fg='red'):
         super().__init__(message)
